@@ -36,6 +36,12 @@ class I18nSettings:
     TRUNK_PO_DIR = None
     ''' '''
 
+    def from_dict(self, mapping):
+        ''' 
+
+        '''
+        pass
+
     def from_json(self, string):
         ''' 
 
@@ -54,6 +60,12 @@ class I18nSettings:
         '''
         pass
 
+    def to_dict(self):
+        ''' 
+
+        '''
+        pass
+
     def to_json(self):
         ''' 
 
