@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ConsoleAutocomplete(bpy_types.Operator):
     bl_idname = None
@@ -486,6 +484,9 @@ class ConsoleExec(bpy_types.Operator):
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_rna = None
     ''' '''
 
