@@ -61,7 +61,7 @@ class DATA_PT_shader_fx(ShaderFxButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def draw(self, context):
+    def draw(self, _context):
         ''' 
 
         '''
