@@ -1,12 +1,12 @@
 import sys
 import typing
-from . import handlers
 from . import icons
-from . import translations
 from . import timers
+from . import translations
+from . import handlers
 
 alembic = None
-''' constant value bpy.app.alembic(supported=True, version=(1, 7, 12), version_string=' 1, 7, 12')
+''' constant value bpy.app.alembic(supported=True, version=(1, 7, 16), version_string=' 1, 7, 16')
 '''
 
 autoexec_fail = None
@@ -70,7 +70,7 @@ build_linkflags = None
 '''
 
 build_options = None
-''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, jack=True, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, ...)
+''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, coreaudio=False, jack=True, pulseaudio=True, wasapi=False, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, usd=True, fluid=True, xr_openxr=True, potrace=True, pugixml=True, haru=True)
 '''
 
 build_platform = None
@@ -129,10 +129,6 @@ debug_freestyle = None
 ''' Boolean, for debug info (started with --debug / --debug_* matching this attribute name)
 '''
 
-debug_gpumem = None
-''' Boolean, for debug info (started with --debug / --debug_* matching this attribute name)
-'''
-
 debug_handlers = None
 ''' Boolean, for debug info (started with --debug / --debug_* matching this attribute name)
 '''
@@ -170,7 +166,7 @@ ffmpeg = None
 '''
 
 ocio = None
-''' constant value bpy.app.ocio(supported=True, version=(1, 1, 1), version_string=' 1, 1, 1')
+''' constant value bpy.app.ocio(supported=True, version=(2, 0, 0), version_string=' 2, 0, 0')
 '''
 
 oiio = None
@@ -182,7 +178,7 @@ opensubdiv = None
 '''
 
 openvdb = None
-''' constant value bpy.app.openvdb(supported=True, version=(7, 0, 0), version_string=' 7, 0, 0')
+''' constant value bpy.app.openvdb(supported=True, version=(8, 0, 0), version_string=' 8, 0, 0')
 '''
 
 render_icon_size = None
@@ -202,7 +198,7 @@ tempdir = None
 '''
 
 usd = None
-''' constant value bpy.app.usd(supported=True, version=(0, 20, 5), version_string=' 0, 20, 5')
+''' constant value bpy.app.usd(supported=True, version=(0, 21, 2), version_string=' 0, 21, 2')
 '''
 
 use_event_simulate = None
