@@ -51,8 +51,18 @@ def apply_solution_scale(distance: float = 0.0):
     pass
 
 
+def average_tracks(keep_original: bool = True):
+    ''' Average selected tracks into active
+
+    :param keep_original: Keep Original, Keep original tracks
+    :type keep_original: bool
+    '''
+
+    pass
+
+
 def bundles_to_mesh():
-    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py\:299 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$299> _
+    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py\:298 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$298> _
 
     '''
 
@@ -90,7 +100,7 @@ def change_frame(frame: int = 0):
 
 def clean_tracks(frames: int = 0,
                  error: float = 0.0,
-                 action: typing.Union[str, int] = 'SELECT'):
+                 action: typing.Union[int, str] = 'SELECT'):
     ''' Clean tracks with high error values or few frames
 
     :param frames: Tracked Frames, Effect on tracks which are tracked less than specified amount of frames
@@ -98,7 +108,7 @@ def clean_tracks(frames: int = 0,
     :param error: Reprojection Error, Effect on tracks which have got larger reprojection error
     :type error: float
     :param action: Action, Cleanup action to execute * SELECT Select, Select unclean tracks. * DELETE_TRACK Delete Track, Delete unclean tracks. * DELETE_SEGMENTS Delete Segments, Delete unclean segments of tracks.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -112,12 +122,12 @@ def clear_solution():
     pass
 
 
-def clear_track_path(action: typing.Union[str, int] = 'REMAINED',
+def clear_track_path(action: typing.Union[int, str] = 'REMAINED',
                      clear_active: bool = False):
     ''' Clear tracks after/before current position or clear the whole track
 
     :param action: Action, Clear action to execute * UPTO Clear Up To, Clear path up to current frame. * REMAINED Clear Remained, Clear path at remaining frames (after current). * ALL Clear All, Clear the whole path.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     :param clear_active: Clear Active, Clear active track only instead of all selected tracks
     :type clear_active: bool
     '''
@@ -126,7 +136,7 @@ def clear_track_path(action: typing.Union[str, int] = 'REMAINED',
 
 
 def constraint_to_fcurve():
-    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py\:543 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$543> _
+    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py\:544 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$544> _
 
     '''
 
@@ -183,14 +193,14 @@ def delete_track():
     pass
 
 
-def detect_features(placement: typing.Union[str, int] = 'FRAME',
+def detect_features(placement: typing.Union[int, str] = 'FRAME',
                     margin: int = 16,
                     threshold: float = 0.5,
                     min_distance: int = 120):
     ''' Automatically detect features and place markers to track
 
     :param placement: Placement, Placement for detected features * FRAME Whole Frame, Place markers across the whole frame. * INSIDE_GPENCIL Inside Annotated Area, Place markers only inside areas outlined with the Annotation tool. * OUTSIDE_GPENCIL Outside Annotated Area, Place markers only outside areas outlined with the Annotation tool.
-    :type placement: typing.Union[str, int]
+    :type placement: typing.Union[int, str]
     :param margin: Margin, Only features further than margin pixels from the image edges are considered
     :type margin: int
     :param threshold: Threshold, Threshold level to consider feature good enough for tracking
@@ -202,11 +212,11 @@ def detect_features(placement: typing.Union[str, int] = 'FRAME',
     pass
 
 
-def disable_markers(action: typing.Union[str, int] = 'DISABLE'):
+def disable_markers(action: typing.Union[int, str] = 'DISABLE'):
     ''' Disable/enable selected markers
 
     :param action: Action, Disable action to execute * DISABLE Disable, Disable selected markers. * ENABLE Enable, Enable selected markers. * TOGGLE Toggle, Toggle disabled flag for selected markers.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -243,11 +253,11 @@ def filter_tracks(track_threshold: float = 5.0):
     pass
 
 
-def frame_jump(position: typing.Union[str, int] = 'PATHSTART'):
+def frame_jump(position: typing.Union[int, str] = 'PATHSTART'):
     ''' Jump to special frame
 
     :param position: Position, Position to jump to * PATHSTART Path Start, Jump to start of current path. * PATHEND Path End, Jump to end of current path. * FAILEDPREV Previous Failed, Jump to previous failed frame. * FAILNEXT Next Failed, Jump to next failed frame.
-    :type position: typing.Union[str, int]
+    :type position: typing.Union[int, str]
     '''
 
     pass
@@ -277,11 +287,11 @@ def graph_delete_knot():
     pass
 
 
-def graph_disable_markers(action: typing.Union[str, int] = 'DISABLE'):
+def graph_disable_markers(action: typing.Union[int, str] = 'DISABLE'):
     ''' Disable/enable selected markers
 
     :param action: Action, Disable action to execute * DISABLE Disable, Disable selected markers. * ENABLE Enable, Enable selected markers. * TOGGLE Toggle, Toggle disabled flag for selected markers.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -300,11 +310,11 @@ def graph_select(location: typing.List[float] = (0.0, 0.0),
     pass
 
 
-def graph_select_all_markers(action: typing.Union[str, int] = 'TOGGLE'):
+def graph_select_all_markers(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection of all markers of active track
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -396,21 +406,21 @@ def lock_selection_toggle():
     pass
 
 
-def lock_tracks(action: typing.Union[str, int] = 'LOCK'):
+def lock_tracks(action: typing.Union[int, str] = 'LOCK'):
     ''' Lock/unlock selected tracks
 
     :param action: Action, Lock action to execute * LOCK Lock, Lock selected tracks. * UNLOCK Unlock, Unlock selected tracks. * TOGGLE Toggle, Toggle locked flag for selected tracks.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def mode_set(mode: typing.Union[str, int] = 'TRACKING'):
+def mode_set(mode: typing.Union[int, str] = 'TRACKING'):
     ''' Set the clip interaction mode
 
     :param mode: Mode * TRACKING Tracking, Show tracking and solving tools. * MASK Mask, Show mask editing tools.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -442,8 +452,8 @@ def open(directory: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: typing.Union[str, int] = 'DEFAULT',
-         sort_method: typing.Union[str, int] = ''):
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = ''):
     ''' Load a sequence of frames or a movie file
 
     :param directory: Directory, Directory of the file
@@ -493,9 +503,9 @@ def open(directory: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -559,11 +569,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection of all tracking markers
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -574,7 +584,7 @@ def select_box(xmin: int = 0,
                ymin: int = 0,
                ymax: int = 0,
                wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET'):
+               mode: typing.Union[int, str] = 'SET'):
     ''' Select markers using box selection
 
     :param xmin: X Min
@@ -588,7 +598,7 @@ def select_box(xmin: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -598,7 +608,7 @@ def select_circle(x: int = 0,
                   y: int = 0,
                   radius: int = 25,
                   wait_for_input: bool = True,
-                  mode: typing.Union[str, int] = 'SET'):
+                  mode: typing.Union[int, str] = 'SET'):
     ''' Select markers using circle selection
 
     :param x: X
@@ -610,17 +620,17 @@ def select_circle(x: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_grouped(group: typing.Union[str, int] = 'ESTIMATED'):
+def select_grouped(group: typing.Union[int, str] = 'ESTIMATED'):
     ''' Select all tracks from specified group
 
     :param group: Action, Clear action to execute * KEYFRAMED Keyframed Tracks, Select all keyframed tracks. * ESTIMATED Estimated Tracks, Select all estimated tracks. * TRACKED Tracked Tracks, Select all tracked tracks. * LOCKED Locked Tracks, Select all locked tracks. * DISABLED Disabled Tracks, Select all disabled tracks. * COLOR Tracks with Same Color, Select all tracks with same color as active track. * FAILED Failed Tracks, Select all tracks which failed to be reconstructed.
-    :type group: typing.Union[str, int]
+    :type group: typing.Union[int, str]
     '''
 
     pass
@@ -629,31 +639,31 @@ def select_grouped(group: typing.Union[str, int] = 'ESTIMATED'):
 def select_lasso(path: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
         List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[str, int] = 'SET'):
+                 mode: typing.Union[int, str] = 'SET'):
     ''' Select markers using lasso selection
 
     :param path: Path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
 
 
 def set_active_clip():
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/clip.py\:228 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$228> _
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/clip.py\:227 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$227> _
 
     '''
 
     pass
 
 
-def set_axis(axis: typing.Union[str, int] = 'X'):
+def set_axis(axis: typing.Union[int, str] = 'X'):
     ''' Set direction of scene axis rotating camera (or its parent if present) and assume selected track lies on real axis, joining it with the origin
 
     :param axis: Axis, Axis to use to align bundle along * X X, Align bundle align X axis. * Y Y, Align bundle align Y axis.
-    :type axis: typing.Union[str, int]
+    :type axis: typing.Union[int, str]
     '''
 
     pass
@@ -677,11 +687,11 @@ def set_origin(use_median: bool = False):
     pass
 
 
-def set_plane(plane: typing.Union[str, int] = 'FLOOR'):
+def set_plane(plane: typing.Union[int, str] = 'FLOOR'):
     ''' Set plane based on 3 selected bundles by moving camera (or its parent if present) in 3D space
 
     :param plane: Plane, Plane to be used for orientation * FLOOR Floor, Set floor plane. * WALL Wall, Set wall plane.
-    :type plane: typing.Union[str, int]
+    :type plane: typing.Union[int, str]
     '''
 
     pass
@@ -715,18 +725,18 @@ def set_solution_scale(distance: float = 0.0):
     pass
 
 
-def set_solver_keyframe(keyframe: typing.Union[str, int] = 'KEYFRAME_A'):
+def set_solver_keyframe(keyframe: typing.Union[int, str] = 'KEYFRAME_A'):
     ''' Set keyframe used by solver
 
     :param keyframe: Keyframe, Keyframe to set
-    :type keyframe: typing.Union[str, int]
+    :type keyframe: typing.Union[int, str]
     '''
 
     pass
 
 
 def set_viewport_background():
-    ''' Set current movie clip as a camera background in 3D Viewport (works only when a 3D Viewport is visible) :file: startup/bl_operators/clip.py\:433 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$433> _
+    ''' Set current movie clip as a camera background in 3D Viewport (works only when a 3D Viewport is visible) :file: startup/bl_operators/clip.py\:434 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$434> _
 
     '''
 
@@ -734,7 +744,7 @@ def set_viewport_background():
 
 
 def setup_tracking_scene():
-    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py\:997 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$997> _
+    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py\:998 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$998> _
 
     '''
 
@@ -852,7 +862,7 @@ def track_markers(backwards: bool = False, sequence: bool = False):
 
 
 def track_settings_as_default():
-    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py\:1028 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1028> _
+    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py\:1029 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1029> _
 
     '''
 
@@ -860,7 +870,7 @@ def track_settings_as_default():
 
 
 def track_settings_to_track():
-    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py\:1076 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1076> _
+    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py\:1077 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1077> _
 
     '''
 
@@ -868,7 +878,7 @@ def track_settings_to_track():
 
 
 def track_to_empty():
-    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py\:275 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$275> _
+    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py\:274 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$274> _
 
     '''
 
