@@ -48,8 +48,8 @@ def lib_id_load_custom_preview(
         filemode: int = 9,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = ''):
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = ''):
     ''' Choose an image to help identify the data-block visually
 
     :param filepath: File Path, Path to file
@@ -95,9 +95,9 @@ def lib_id_load_custom_preview(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
