@@ -9,24 +9,24 @@ def fbx(filepath: str = "",
         use_active_collection: bool = False,
         global_scale: float = 1.0,
         apply_unit_scale: bool = True,
-        apply_scale_options: typing.Union[str, int] = 'FBX_SCALE_NONE',
+        apply_scale_options: typing.Union[int, str] = 'FBX_SCALE_NONE',
         use_space_transform: bool = True,
         bake_space_transform: bool = False,
-        object_types: typing.Union[typing.Set[str], typing.Set[int]] = {
+        object_types: typing.Union[typing.Set[int], typing.Set[str]] = {
             'ARMATURE', 'CAMERA', 'EMPTY', 'LIGHT', 'MESH', 'OTHER'
         },
         use_mesh_modifiers: bool = True,
         use_mesh_modifiers_render: bool = True,
-        mesh_smooth_type: typing.Union[str, int] = 'OFF',
+        mesh_smooth_type: typing.Union[int, str] = 'OFF',
         use_subsurf: bool = False,
         use_mesh_edges: bool = False,
         use_tspace: bool = False,
         use_custom_props: bool = False,
         add_leaf_bones: bool = True,
-        primary_bone_axis: typing.Union[str, int] = 'Y',
-        secondary_bone_axis: typing.Union[str, int] = 'X',
+        primary_bone_axis: typing.Union[int, str] = 'Y',
+        secondary_bone_axis: typing.Union[int, str] = 'X',
         use_armature_deform_only: bool = False,
-        armature_nodetype: typing.Union[str, int] = 'NULL',
+        armature_nodetype: typing.Union[int, str] = 'NULL',
         bake_anim: bool = True,
         bake_anim_use_all_bones: bool = True,
         bake_anim_use_nla_strips: bool = True,
@@ -34,13 +34,13 @@ def fbx(filepath: str = "",
         bake_anim_force_startend_keying: bool = True,
         bake_anim_step: float = 1.0,
         bake_anim_simplify_factor: float = 1.0,
-        path_mode: typing.Union[str, int] = 'AUTO',
+        path_mode: typing.Union[int, str] = 'AUTO',
         embed_textures: bool = False,
-        batch_mode: typing.Union[str, int] = 'OFF',
+        batch_mode: typing.Union[int, str] = 'OFF',
         use_batch_own_dir: bool = True,
         use_metadata: bool = True,
-        axis_forward: typing.Union[str, int] = '-Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        axis_forward: typing.Union[int, str] = '-Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Write a FBX file
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -58,19 +58,19 @@ def fbx(filepath: str = "",
     :param apply_unit_scale: Apply Unit, Take into account current Blender units settings (if unset, raw Blender Units values are used as-is)
     :type apply_unit_scale: bool
     :param apply_scale_options: Apply Scalings, How to apply custom and units scalings in generated FBX file (Blender uses FBX scale to detect units on import, but many other applications do not handle the same way) * FBX_SCALE_NONE All Local, Apply custom scaling and units scaling to each object transformation, FBX scale remains at 1.0. * FBX_SCALE_UNITS FBX Units Scale, Apply custom scaling to each object transformation, and units scaling to FBX scale. * FBX_SCALE_CUSTOM FBX Custom Scale, Apply custom scaling to FBX scale, and units scaling to each object transformation. * FBX_SCALE_ALL FBX All, Apply custom scaling and units scaling to FBX scale.
-    :type apply_scale_options: typing.Union[str, int]
+    :type apply_scale_options: typing.Union[int, str]
     :param use_space_transform: Use Space Transform, Apply global space transform to the object rotations. When disabled only the axis space is written to the file and all object transforms are left as-is
     :type use_space_transform: bool
     :param bake_space_transform: Apply Transform, Bake space transform into object data, avoids getting unwanted rotations to objects when target space is not aligned with Blender's space (WARNING! experimental option, use at own risks, known broken with armatures/animations)
     :type bake_space_transform: bool
     :param object_types: Object Types, Which kind of object to export * EMPTY Empty. * CAMERA Camera. * LIGHT Lamp. * ARMATURE Armature, WARNING: not supported in dupli/group instances. * MESH Mesh. * OTHER Other, Other geometry types, like curve, metaball, etc. (converted to meshes).
-    :type object_types: typing.Union[typing.Set[str], typing.Set[int]]
+    :type object_types: typing.Union[typing.Set[int], typing.Set[str]]
     :param use_mesh_modifiers: Apply Modifiers, Apply modifiers to mesh objects (except Armature ones) - WARNING: prevents exporting shape keys
     :type use_mesh_modifiers: bool
     :param use_mesh_modifiers_render: Use Modifiers Render Setting, Use render settings when applying modifiers to mesh objects (DISABLED in Blender 2.8)
     :type use_mesh_modifiers_render: bool
     :param mesh_smooth_type: Smoothing, Export smoothing information (prefer 'Normals Only' option if your target importer understand split normals) * OFF Normals Only, Export only normals instead of writing edge or face smoothing data. * FACE Face, Write face smoothing. * EDGE Edge, Write edge smoothing.
-    :type mesh_smooth_type: typing.Union[str, int]
+    :type mesh_smooth_type: typing.Union[int, str]
     :param use_subsurf: Export Subdivision Surface, Export the last Catmull-Rom subdivision modifier as FBX subdivision (does not apply the modifier even if 'Apply Modifiers' is enabled)
     :type use_subsurf: bool
     :param use_mesh_edges: Loose Edges, Export loose edges (as two-vertices polygons)
@@ -82,13 +82,13 @@ def fbx(filepath: str = "",
     :param add_leaf_bones: Add Leaf Bones, Append a final bone to the end of each chain to specify last bone length (use this when you intend to edit the armature from exported data)
     :type add_leaf_bones: bool
     :param primary_bone_axis: Primary Bone Axis
-    :type primary_bone_axis: typing.Union[str, int]
+    :type primary_bone_axis: typing.Union[int, str]
     :param secondary_bone_axis: Secondary Bone Axis
-    :type secondary_bone_axis: typing.Union[str, int]
+    :type secondary_bone_axis: typing.Union[int, str]
     :param use_armature_deform_only: Only Deform Bones, Only write deforming bones (and non-deforming ones when they have deforming children)
     :type use_armature_deform_only: bool
     :param armature_nodetype: Armature FBXNode Type, FBX type of node (object) used to represent Blender's armatures (use Null one unless you experience issues with other app, other choices may no import back perfectly in Blender...) * NULL Null, 'Null' FBX node, similar to Blender's Empty (default). * ROOT Root, 'Root' FBX node, supposed to be the root of chains of bones.... * LIMBNODE LimbNode, 'LimbNode' FBX node, a regular joint between two bones....
-    :type armature_nodetype: typing.Union[str, int]
+    :type armature_nodetype: typing.Union[int, str]
     :param bake_anim: Baked Animation, Export baked keyframe animation
     :type bake_anim: bool
     :param bake_anim_use_all_bones: Key All Bones, Force exporting at least one key of animation for all bones (needed with some target applications, like UE4)
@@ -104,19 +104,19 @@ def fbx(filepath: str = "",
     :param bake_anim_simplify_factor: Simplify, How much to simplify baked values (0.0 to disable, the higher the more simplified)
     :type bake_anim_simplify_factor: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[str, int]
+    :type path_mode: typing.Union[int, str]
     :param embed_textures: Embed Textures, Embed textures in FBX binary file (only for "Copy" path mode!)
     :type embed_textures: bool
     :param batch_mode: Batch Mode * OFF Off, Active scene to file. * SCENE Scene, Each scene as a file. * COLLECTION Collection, Each collection (data-block ones) as a file, does not include content of children collections. * SCENE_COLLECTION Scene Collections, Each collection (including master, non-data-block ones) of each scene as a file, including content from children collections. * ACTIVE_SCENE_COLLECTION Active Scene Collections, Each collection (including master, non-data-block one) of the active scene as a file, including content from children collections.
-    :type batch_mode: typing.Union[str, int]
+    :type batch_mode: typing.Union[int, str]
     :param use_batch_own_dir: Batch Own Dir, Create a dir for each exported file
     :type use_batch_own_dir: bool
     :param use_metadata: Use Metadata
     :type use_metadata: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
@@ -124,10 +124,10 @@ def fbx(filepath: str = "",
 
 def gltf(filepath: str = "",
          check_existing: bool = True,
-         export_format: typing.Union[str, int] = 'GLB',
-         ui_tab: typing.Union[str, int] = 'GENERAL',
+         export_format: typing.Union[int, str] = 'GLB',
+         ui_tab: typing.Union[int, str] = 'GENERAL',
          export_copyright: str = "",
-         export_image_format: typing.Union[str, int] = 'AUTO',
+         export_image_format: typing.Union[int, str] = 'AUTO',
          export_texture_dir: str = "",
          export_texcoords: bool = True,
          export_normals: bool = True,
@@ -139,7 +139,7 @@ def gltf(filepath: str = "",
          export_draco_color_quantization: int = 10,
          export_draco_generic_quantization: int = 12,
          export_tangents: bool = False,
-         export_materials: typing.Union[str, int] = 'EXPORT',
+         export_materials: typing.Union[int, str] = 'EXPORT',
          export_colors: bool = True,
          use_mesh_edges: bool = False,
          use_mesh_vertices: bool = False,
@@ -175,13 +175,13 @@ def gltf(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param export_format: Format, Output format and embedding options. Binary is most efficient, but JSON (embedded or separate) may be easier to edit later * GLB glTF Binary (.glb), Exports a single file, with all data packed in binary form. Most efficient and portable, but more difficult to edit later. * GLTF_EMBEDDED glTF Embedded (.gltf), Exports a single file, with all data packed in JSON. Less efficient than binary, but easier to edit later. * GLTF_SEPARATE glTF Separate (.gltf + .bin + textures), Exports multiple files, with separate JSON, binary and texture data. Easiest to edit later.
-    :type export_format: typing.Union[str, int]
+    :type export_format: typing.Union[int, str]
     :param ui_tab: ui_tab, Export setting categories * GENERAL General, General settings. * MESHES Meshes, Mesh settings. * OBJECTS Objects, Object settings. * ANIMATION Animation, Animation settings.
-    :type ui_tab: typing.Union[str, int]
+    :type ui_tab: typing.Union[int, str]
     :param export_copyright: Copyright, Legal rights and conditions for the model
     :type export_copyright: str
     :param export_image_format: Images, Output format for images. PNG is lossless and generally preferred, but JPEG might be preferable for web applications due to the smaller file size * AUTO Automatic, Save PNGs as PNGs and JPEGs as JPEGs. If neither one, use PNG. * JPEG JPEG Format (.jpg), Save images as JPEGs. (Images that need alpha are saved as PNGs though.) Be aware of a possible loss in quality.
-    :type export_image_format: typing.Union[str, int]
+    :type export_image_format: typing.Union[int, str]
     :param export_texture_dir: Textures, Folder to place texture files in. Relative to the .gltf file
     :type export_texture_dir: str
     :param export_texcoords: UVs, Export UVs (texture coordinates) with meshes
@@ -205,7 +205,7 @@ def gltf(filepath: str = "",
     :param export_tangents: Tangents, Export vertex tangents with meshes
     :type export_tangents: bool
     :param export_materials: Materials, Export materials * EXPORT Export, Export all materials used by included objects. * PLACEHOLDER Placeholder, Do not export materials, but write multiple primitive groups per mesh, keeping material slot information. * NONE No export, Do not export materials, and combine mesh primitive groups, losing material slot information.
-    :type export_materials: typing.Union[str, int]
+    :type export_materials: typing.Union[int, str]
     :param export_colors: Vertex Colors, Export vertex colors with meshes
     :type export_colors: bool
     :param use_mesh_edges: Loose Edges, Export loose edges as lines, using the material from the first material slot
@@ -287,9 +287,9 @@ def obj(filepath: str = "",
         group_by_material: bool = False,
         keep_vertex_order: bool = False,
         global_scale: float = 1.0,
-        path_mode: typing.Union[str, int] = 'AUTO',
-        axis_forward: typing.Union[str, int] = '-Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        path_mode: typing.Union[int, str] = 'AUTO',
+        axis_forward: typing.Union[int, str] = '-Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Save a Wavefront OBJ File
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -333,11 +333,11 @@ def obj(filepath: str = "",
     :param global_scale: Scale
     :type global_scale: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[str, int]
+    :type path_mode: typing.Union[int, str]
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
@@ -355,9 +355,9 @@ def x3d(filepath: str = "",
         name_decorations: bool = True,
         use_h3d: bool = False,
         global_scale: float = 1.0,
-        path_mode: typing.Union[str, int] = 'AUTO',
-        axis_forward: typing.Union[str, int] = 'Z',
-        axis_up: typing.Union[str, int] = 'Y'):
+        path_mode: typing.Union[int, str] = 'AUTO',
+        axis_forward: typing.Union[int, str] = 'Z',
+        axis_up: typing.Union[int, str] = 'Y'):
     ''' Export selection to Extensible 3D file (.x3d)
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -385,11 +385,11 @@ def x3d(filepath: str = "",
     :param global_scale: Scale
     :type global_scale: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[str, int]
+    :type path_mode: typing.Union[int, str]
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[str, int]
+    :type axis_forward: typing.Union[int, str]
     :param axis_up: Up
-    :type axis_up: typing.Union[str, int]
+    :type axis_up: typing.Union[int, str]
     '''
 
     pass
