@@ -36,11 +36,11 @@ def bookmark_delete(index: int = -1):
     pass
 
 
-def bookmark_move(direction: typing.Union[str, int] = 'TOP'):
+def bookmark_move(direction: typing.Union[int, str] = 'TOP'):
     ''' Move the active bookmark up/down in the list
 
     :param direction: Direction, Direction to move the active bookmark towards * TOP Top, Top of the list. * UP Up. * DOWN Down. * BOTTOM Bottom, Bottom of the list.
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -127,8 +127,8 @@ def find_missing_files(find_all: bool = False,
                        filter_folder: bool = False,
                        filter_blenlib: bool = False,
                        filemode: int = 9,
-                       display_type: typing.Union[str, int] = 'DEFAULT',
-                       sort_method: typing.Union[str, int] = ''):
+                       display_type: typing.Union[int, str] = 'DEFAULT',
+                       sort_method: typing.Union[int, str] = ''):
     ''' Try to find missing external files
 
     :param find_all: Find All, Find all files in the search path (not just missing)
@@ -172,9 +172,9 @@ def find_missing_files(find_all: bool = False,
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -303,11 +303,11 @@ def select(extend: bool = False,
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Select or deselect all files
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -328,7 +328,7 @@ def select_box(xmin: int = 0,
                ymin: int = 0,
                ymax: int = 0,
                wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET'):
+               mode: typing.Union[int, str] = 'SET'):
     ''' Activate/select the file(s) contained in the border
 
     :param xmin: X Min
@@ -342,19 +342,19 @@ def select_box(xmin: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_walk(direction: typing.Union[str, int] = 'UP',
+def select_walk(direction: typing.Union[int, str] = 'UP',
                 extend: bool = False,
                 fill: bool = False):
     ''' Select/Deselect files by walking through them
 
     :param direction: Walk Direction, Select/Deselect element in this direction
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param fill: Fill, Select everything beginning with the last selection
@@ -388,23 +388,23 @@ def start_filter():
     pass
 
 
-def unpack_all(method: typing.Union[str, int] = 'USE_LOCAL'):
+def unpack_all(method: typing.Union[int, str] = 'USE_LOCAL'):
     ''' Unpack all files packed into this .blend to external ones
 
     :param method: Method, How to unpack
-    :type method: typing.Union[str, int]
+    :type method: typing.Union[int, str]
     '''
 
     pass
 
 
-def unpack_item(method: typing.Union[str, int] = 'USE_LOCAL',
+def unpack_item(method: typing.Union[int, str] = 'USE_LOCAL',
                 id_name: str = "",
                 id_type: int = 19785):
     ''' Unpack this file to an external file
 
     :param method: Method, How to unpack
-    :type method: typing.Union[str, int]
+    :type method: typing.Union[int, str]
     :param id_name: ID Name, Name of ID block to unpack
     :type id_name: str
     :param id_type: ID Type, Identifier type of ID block
@@ -420,3 +420,11 @@ def unpack_libraries():
     '''
 
     pass
+
+
+def view_selected():
+    ''' Scroll the selected files into view
+
+    '''
+
+    pass
