@@ -37,12 +37,12 @@ def clear_render_slot():
     pass
 
 
-def curves_point_set(point: typing.Union[str, int] = 'BLACK_POINT',
+def curves_point_set(point: typing.Union[int, str] = 'BLACK_POINT',
                      size: int = 1):
     ''' Set black point or white point for curves
 
     :param point: Point, Set black point or white point for curves
-    :type point: typing.Union[str, int]
+    :type point: typing.Union[int, str]
     :param size: Sample Size
     :type size: int
     '''
@@ -70,6 +70,18 @@ def external_edit(filepath: str = ""):
     pass
 
 
+def flip(use_flip_horizontal: bool = False, use_flip_vertical: bool = False):
+    ''' Flip the image
+
+    :param use_flip_horizontal: Horizontal, Flip the image horizontally
+    :type use_flip_horizontal: bool
+    :param use_flip_vertical: Vertical, Flip the image vertically
+    :type use_flip_vertical: bool
+    '''
+
+    pass
+
+
 def invert(invert_r: bool = False,
            invert_g: bool = False,
            invert_b: bool = False,
@@ -102,7 +114,7 @@ def new(name: str = "Untitled",
         height: int = 1024,
         color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
         alpha: bool = True,
-        generated_type: typing.Union[str, int] = 'BLANK',
+        generated_type: typing.Union[int, str] = 'BLANK',
         float: bool = False,
         use_stereo_3d: bool = False,
         tiled: bool = False):
@@ -119,7 +131,7 @@ def new(name: str = "Untitled",
     :param alpha: Alpha, Create an image with an alpha channel
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[str, int]
+    :type generated_type: typing.Union[int, str]
     :param float: 32-bit Float, Create image with 32-bit floating-point bit depth
     :type float: bool
     :param use_stereo_3d: Stereo 3D, Create an image with left and right views
@@ -158,8 +170,8 @@ def open(filepath: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: typing.Union[str, int] = 'DEFAULT',
-         sort_method: typing.Union[str, int] = '',
+         display_type: typing.Union[int, str] = 'DEFAULT',
+         sort_method: typing.Union[int, str] = '',
          use_sequence_detection: bool = True,
          use_udim_detecting: bool = True):
     ''' Open image
@@ -213,9 +225,9 @@ def open(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param use_sequence_detection: Detect Sequences, Automatically detect animated sequences in selected images (based on file names)
     :type use_sequence_detection: bool
     :param use_udim_detecting: Detect UDIMs, Detect selected UDIM files and load all matching tiles
@@ -317,8 +329,8 @@ def replace(filepath: str = "",
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[str, int] = 'DEFAULT',
-            sort_method: typing.Union[str, int] = ''):
+            display_type: typing.Union[int, str] = 'DEFAULT',
+            sort_method: typing.Union[int, str] = ''):
     ''' Replace current image by another one from disk
 
     :param filepath: File Path, Path to file
@@ -366,9 +378,9 @@ def replace(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -459,8 +471,8 @@ def save_as(save_as_render: bool = False,
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[str, int] = 'DEFAULT',
-            sort_method: typing.Union[str, int] = ''):
+            display_type: typing.Union[int, str] = 'DEFAULT',
+            sort_method: typing.Union[int, str] = ''):
     ''' Save the image with another name and/or settings
 
     :param save_as_render: Save As Render, Apply render part of display transform when saving byte image
@@ -512,9 +524,9 @@ def save_as(save_as_render: bool = False,
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
@@ -533,7 +545,7 @@ def tile_add(number: int = 1002,
              label: str = "",
              fill: bool = True,
              color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
-             generated_type: typing.Union[str, int] = 'BLANK',
+             generated_type: typing.Union[int, str] = 'BLANK',
              width: int = 1024,
              height: int = 1024,
              float: bool = False,
@@ -551,7 +563,7 @@ def tile_add(number: int = 1002,
     :param color: Color, Default fill color
     :type color: typing.List[float]
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[str, int]
+    :type generated_type: typing.Union[int, str]
     :param width: Width, Image width
     :type width: int
     :param height: Height, Image height
@@ -566,7 +578,7 @@ def tile_add(number: int = 1002,
 
 
 def tile_fill(color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
-              generated_type: typing.Union[str, int] = 'BLANK',
+              generated_type: typing.Union[int, str] = 'BLANK',
               width: int = 1024,
               height: int = 1024,
               float: bool = False,
@@ -576,7 +588,7 @@ def tile_fill(color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
     :param color: Color, Default fill color
     :type color: typing.List[float]
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[str, int]
+    :type generated_type: typing.Union[int, str]
     :param width: Width, Image width
     :type width: int
     :param height: Height, Image height
@@ -598,11 +610,11 @@ def tile_remove():
     pass
 
 
-def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
+def unpack(method: typing.Union[int, str] = 'USE_LOCAL', id: str = ""):
     ''' Save an image packed in the .blend file to disk
 
     :param method: Method, How to unpack
-    :type method: typing.Union[str, int]
+    :type method: typing.Union[int, str]
     :param id: Image Name, Image data-block name to unpack
     :type id: str
     '''
@@ -628,6 +640,16 @@ def view_center_cursor():
     pass
 
 
+def view_cursor_center(fit_view: bool = False):
+    ''' Set 2D Cursor To Center View location
+
+    :param fit_view: Fit View, Fit frame to the viewport
+    :type fit_view: bool
+    '''
+
+    pass
+
+
 def view_ndof():
     ''' Use a 3D mouse device to pan/zoom the view
 
