@@ -49,11 +49,11 @@ def reveal_metaelems(select: bool = True):
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Change selection of all metaball elements
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -61,7 +61,7 @@ def select_all(action: typing.Union[str, int] = 'TOGGLE'):
 
 def select_random_metaelems(ratio: float = 0.5,
                             seed: int = 0,
-                            action: typing.Union[str, int] = 'SELECT'):
+                            action: typing.Union[int, str] = 'SELECT'):
     ''' Randomly select metaball elements
 
     :param ratio: Ratio, Portion of items to select randomly
@@ -69,18 +69,18 @@ def select_random_metaelems(ratio: float = 0.5,
     :param seed: Random Seed, Seed for the random number generator
     :type seed: int
     :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
 
 
-def select_similar(type: typing.Union[str, int] = 'TYPE',
+def select_similar(type: typing.Union[int, str] = 'TYPE',
                    threshold: float = 0.1):
     ''' Select similar metaballs by property types
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param threshold: Threshold
     :type threshold: float
     '''
