@@ -3,21 +3,21 @@ import typing
 import bpy.types
 
 
-def change_effect_input(swap: typing.Union[str, int] = 'A_B'):
+def change_effect_input(swap: typing.Union[int, str] = 'A_B'):
     ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param swap: Swap, The effect inputs to swap
-    :type swap: typing.Union[str, int]
+    :type swap: typing.Union[int, str]
     '''
 
     pass
 
 
-def change_effect_type(type: typing.Union[str, int] = 'CROSS'):
+def change_effect_type(type: typing.Union[int, str] = 'CROSS'):
     ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param type: Type, Sequencer effect type * CROSS Crossfade, Crossfade effect strip type. * ADD Add, Add effect strip type. * SUBTRACT Subtract, Subtract effect strip type. * ALPHA_OVER Alpha Over, Alpha Over effect strip type. * ALPHA_UNDER Alpha Under, Alpha Under effect strip type. * GAMMA_CROSS Gamma Cross, Gamma Cross effect strip type. * MULTIPLY Multiply, Multiply effect strip type. * OVER_DROP Alpha Over Drop, Alpha Over Drop effect strip type. * WIPE Wipe, Wipe effect strip type. * GLOW Glow, Glow effect strip type. * TRANSFORM Transform, Transform effect strip type. * COLOR Color, Color effect strip type. * SPEED Speed, Color effect strip type. * MULTICAM Multicam Selector. * ADJUSTMENT Adjustment Layer. * GAUSSIAN_BLUR Gaussian Blur. * TEXT Text. * COLORMIX Color Mix.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -49,8 +49,8 @@ def change_path(
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = '',
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = '',
         use_placeholders: bool = False):
     ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
@@ -99,9 +99,9 @@ def change_path(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param use_placeholders: Use Placeholders, Use placeholders for missing frames of the strip
     :type use_placeholders: bool
     '''
@@ -159,7 +159,7 @@ def duplicate_move(SEQUENCER_OT_duplicate=None, TRANSFORM_OT_seq_slide=None):
     pass
 
 
-def effect_strip_add(type: typing.Union[str, int] = 'CROSS',
+def effect_strip_add(type: typing.Union[int, str] = 'CROSS',
                      frame_start: int = 0,
                      frame_end: int = 0,
                      channel: int = 1,
@@ -169,7 +169,7 @@ def effect_strip_add(type: typing.Union[str, int] = 'CROSS',
     ''' Add an effect to the sequencer, most are applied on top of existing strips
 
     :param type: Type, Sequencer effect type * CROSS Crossfade, Crossfade effect strip type. * ADD Add, Add effect strip type. * SUBTRACT Subtract, Subtract effect strip type. * ALPHA_OVER Alpha Over, Alpha Over effect strip type. * ALPHA_UNDER Alpha Under, Alpha Under effect strip type. * GAMMA_CROSS Gamma Cross, Gamma Cross effect strip type. * MULTIPLY Multiply, Multiply effect strip type. * OVER_DROP Alpha Over Drop, Alpha Over Drop effect strip type. * WIPE Wipe, Wipe effect strip type. * GLOW Glow, Glow effect strip type. * TRANSFORM Transform, Transform effect strip type. * COLOR Color, Color effect strip type. * SPEED Speed, Color effect strip type. * MULTICAM Multicam Selector. * ADJUSTMENT Adjustment Layer. * GAUSSIAN_BLUR Gaussian Blur. * TEXT Text. * COLORMIX Color Mix.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param frame_end: End Frame, End frame for the color strip
@@ -229,8 +229,8 @@ def export_subtitles(filepath: str = "",
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
-                     display_type: typing.Union[str, int] = 'DEFAULT',
-                     sort_method: typing.Union[str, int] = ''):
+                     display_type: typing.Union[int, str] = 'DEFAULT',
+                     sort_method: typing.Union[int, str] = ''):
     ''' Export .srt file containing text strips
 
     :param filepath: File Path, Path to file
@@ -274,22 +274,22 @@ def export_subtitles(filepath: str = "",
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
 
 
 def fades_add(duration_seconds: float = 1.0,
-              type: typing.Union[str, int] = 'IN_OUT'):
+              type: typing.Union[int, str] = 'IN_OUT'):
     ''' Adds or updates a fade animation for either visual or audio strips
 
     :param duration_seconds: Fade Duration, Duration of the fade in seconds
     :type duration_seconds: float
     :param type: Fade Type, Fade in, out, both in and out, to, or from the current frame. Default is both in and out * IN_OUT Fade In and Out, Fade selected strips in and out. * IN Fade In, Fade in selected strips. * OUT Fade Out, Fade out selected strips. * CURSOR_FROM From Current Frame, Fade from the time cursor to the end of overlapping sequences. * CURSOR_TO To Current Frame, Fade from the start of sequences under the time cursor to the current frame.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -349,14 +349,14 @@ def image_strip_add(
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = '',
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = '',
         frame_start: int = 0,
         frame_end: int = 0,
         channel: int = 1,
         replace_sel: bool = True,
         overlap: bool = False,
-        fit_method: typing.Union[str, int] = 'FIT',
+        fit_method: typing.Union[int, str] = 'FIT',
         set_view_transform: bool = True,
         use_placeholders: bool = False):
     ''' Add an image or image sequence to the sequencer
@@ -406,9 +406,9 @@ def image_strip_add(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param frame_end: End Frame, End frame for the color strip
@@ -420,7 +420,7 @@ def image_strip_add(
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param fit_method: Fit Method, Scale fit method * FIT Scale to Fit, Scale image to fit within the canvas. * FILL Scale to Fill, Scale image to completely fill the canvas. * STRETCH Stretch to Fill, Stretch image to fill the canvas. * ORIGINAL Use Original Size, Keep image at its original size.
-    :type fit_method: typing.Union[str, int]
+    :type fit_method: typing.Union[int, str]
     :param set_view_transform: Set view transform, Set appropriate view transform based on media colorspace
     :type set_view_transform: bool
     :param use_placeholders: Use Placeholders, Use placeholders for missing frames of the strip
@@ -452,7 +452,7 @@ def mask_strip_add(frame_start: int = 0,
                    channel: int = 1,
                    replace_sel: bool = True,
                    overlap: bool = False,
-                   mask: typing.Union[str, int] = ''):
+                   mask: typing.Union[int, str] = ''):
     ''' Add a mask strip to the sequencer
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -464,7 +464,7 @@ def mask_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param mask: Mask
-    :type mask: typing.Union[str, int]
+    :type mask: typing.Union[int, str]
     '''
 
     pass
@@ -521,13 +521,13 @@ def movie_strip_add(
         relative_path: bool = True,
         show_multiview: bool = False,
         use_multiview: bool = False,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = '',
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = '',
         frame_start: int = 0,
         channel: int = 1,
         replace_sel: bool = True,
         overlap: bool = False,
-        fit_method: typing.Union[str, int] = 'FIT',
+        fit_method: typing.Union[int, str] = 'FIT',
         set_view_transform: bool = True,
         sound: bool = True,
         use_framerate: bool = True):
@@ -580,9 +580,9 @@ def movie_strip_add(
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param channel: Channel, Channel to place this strip into
@@ -592,7 +592,7 @@ def movie_strip_add(
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param fit_method: Fit Method, Scale fit method * FIT Scale to Fit, Scale image to fit within the canvas. * FILL Scale to Fill, Scale image to completely fill the canvas. * STRETCH Stretch to Fill, Stretch image to fill the canvas. * ORIGINAL Use Original Size, Keep image at its original size.
-    :type fit_method: typing.Union[str, int]
+    :type fit_method: typing.Union[int, str]
     :param set_view_transform: Set view transform, Set appropriate view transform based on media colorspace
     :type set_view_transform: bool
     :param sound: Sound, Load sound with the movie
@@ -608,7 +608,7 @@ def movieclip_strip_add(frame_start: int = 0,
                         channel: int = 1,
                         replace_sel: bool = True,
                         overlap: bool = False,
-                        clip: typing.Union[str, int] = ''):
+                        clip: typing.Union[int, str] = ''):
     ''' Add a movieclip strip to the sequencer
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -620,7 +620,7 @@ def movieclip_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param clip: Clip
-    :type clip: typing.Union[str, int]
+    :type clip: typing.Union[int, str]
     '''
 
     pass
@@ -710,7 +710,7 @@ def scene_strip_add(frame_start: int = 0,
                     channel: int = 1,
                     replace_sel: bool = True,
                     overlap: bool = False,
-                    scene: typing.Union[str, int] = ''):
+                    scene: typing.Union[int, str] = ''):
     ''' Add a strip to the sequencer using a blender scene as a source
 
     :param frame_start: Start Frame, Start frame of the sequence strip
@@ -722,7 +722,7 @@ def scene_strip_add(frame_start: int = 0,
     :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
     :type overlap: bool
     :param scene: Scene
-    :type scene: typing.Union[str, int]
+    :type scene: typing.Union[int, str]
     '''
 
     pass
@@ -759,11 +759,11 @@ def select(wait_to_deselect_others: bool = False,
     pass
 
 
-def select_all(action: typing.Union[str, int] = 'TOGGLE'):
+def select_all(action: typing.Union[int, str] = 'TOGGLE'):
     ''' Select or deselect all strips
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[str, int]
+    :type action: typing.Union[int, str]
     '''
 
     pass
@@ -774,7 +774,7 @@ def select_box(xmin: int = 0,
                ymin: int = 0,
                ymax: int = 0,
                wait_for_input: bool = True,
-               mode: typing.Union[str, int] = 'SET',
+               mode: typing.Union[int, str] = 'SET',
                tweak: bool = False,
                include_handles: bool = False):
     ''' Select strips using box selection
@@ -790,7 +790,7 @@ def select_box(xmin: int = 0,
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     :param tweak: Tweak, Operator has been activated using a tweak event
     :type tweak: bool
     :param include_handles: Select Handles, Select the strips and their handles
@@ -800,13 +800,13 @@ def select_box(xmin: int = 0,
     pass
 
 
-def select_grouped(type: typing.Union[str, int] = 'TYPE',
+def select_grouped(type: typing.Union[int, str] = 'TYPE',
                    extend: bool = False,
                    use_active_channel: bool = False):
     ''' Select all strips grouped by various properties
 
     :param type: Type * TYPE Type, Shared strip type. * TYPE_BASIC Global Type, All strips of same basic type (graphical or sound). * TYPE_EFFECT Effect Type, Shared strip effect type (if active strip is not an effect one, select all non-effect strips). * DATA Data, Shared data (scene, image, sound, etc.). * EFFECT Effect, Shared effects. * EFFECT_LINK Effect/Linked, Other strips affected by the active one (sharing some time, and below or effect-assigned). * OVERLAP Overlap, Overlapping time.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param extend: Extend, Extend selection instead of deselecting everything first
     :type extend: bool
     :param use_active_channel: Same Channel, Only consider strips on the same channel as the active one
@@ -816,11 +816,11 @@ def select_grouped(type: typing.Union[str, int] = 'TYPE',
     pass
 
 
-def select_handles(side: typing.Union[str, int] = 'BOTH'):
+def select_handles(side: typing.Union[int, str] = 'BOTH'):
     ''' Select gizmo handles on the sides of the selected strip
 
     :param side: Side, The side of the handle that is selected
-    :type side: typing.Union[str, int]
+    :type side: typing.Union[int, str]
     '''
 
     pass
@@ -860,24 +860,24 @@ def select_more():
     pass
 
 
-def select_side(side: typing.Union[str, int] = 'BOTH'):
+def select_side(side: typing.Union[int, str] = 'BOTH'):
     ''' Select strips on the nominated side of the selected strips
 
     :param side: Side, The side to which the selection is applied
-    :type side: typing.Union[str, int]
+    :type side: typing.Union[int, str]
     '''
 
     pass
 
 
 def select_side_of_frame(extend: bool = False,
-                         side: typing.Union[str, int] = 'LEFT'):
+                         side: typing.Union[int, str] = 'LEFT'):
     ''' Select strips relative to the current frame
 
     :param extend: Extend, Extend the selection
     :type extend: bool
     :param side: Side * LEFT Left, Select to the left of the current frame. * RIGHT Right, Select to the right of the current frame.
-    :type side: typing.Union[str, int]
+    :type side: typing.Union[int, str]
     '''
 
     pass
@@ -938,8 +938,8 @@ def sound_strip_add(
         filter_blenlib: bool = False,
         filemode: int = 9,
         relative_path: bool = True,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = '',
+        display_type: typing.Union[int, str] = 'DEFAULT',
+        sort_method: typing.Union[int, str] = '',
         frame_start: int = 0,
         channel: int = 1,
         replace_sel: bool = True,
@@ -991,9 +991,9 @@ def sound_strip_add(
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     :param frame_start: Start Frame, Start frame of the sequence strip
     :type frame_start: int
     :param channel: Channel, Channel to place this strip into
@@ -1013,9 +1013,9 @@ def sound_strip_add(
 
 def split(frame: int = 0,
           channel: int = 0,
-          type: typing.Union[str, int] = 'SOFT',
+          type: typing.Union[int, str] = 'SOFT',
           use_cursor_position: bool = False,
-          side: typing.Union[str, int] = 'MOUSE',
+          side: typing.Union[int, str] = 'MOUSE',
           ignore_selection: bool = False):
     ''' Split the selected strips in two
 
@@ -1024,11 +1024,11 @@ def split(frame: int = 0,
     :param channel: Channel, Channel in which strip will be cut
     :type channel: int
     :param type: Type, The type of split operation to perform on strips
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     :param use_cursor_position: Use Cursor Position, Split at position of the cursor instead of current frame
     :type use_cursor_position: bool
     :param side: Side, The side that remains selected after splitting
-    :type side: typing.Union[str, int]
+    :type side: typing.Union[int, str]
     :param ignore_selection: Ignore Selection, Make cut event if strip is not selected preserving selection state after cut
     :type ignore_selection: bool
     '''
@@ -1058,34 +1058,34 @@ def strip_jump(next: bool = True, center: bool = True):
     pass
 
 
-def strip_modifier_add(type: typing.Union[str, int] = 'COLOR_BALANCE'):
+def strip_modifier_add(type: typing.Union[int, str] = 'COLOR_BALANCE'):
     ''' Add a modifier to the strip
 
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def strip_modifier_copy(type: typing.Union[str, int] = 'REPLACE'):
+def strip_modifier_copy(type: typing.Union[int, str] = 'REPLACE'):
     ''' Copy modifiers of the active strip to all selected strips
 
     :param type: Type * REPLACE Replace, Replace modifiers in destination. * APPEND Append, Append active modifiers to selected strips.
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
 def strip_modifier_move(name: str = "Name",
-                        direction: typing.Union[str, int] = 'UP'):
+                        direction: typing.Union[int, str] = 'UP'):
     ''' Move modifier up and down in the stack
 
     :param name: Name, Name of modifier to remove
     :type name: str
     :param direction: Type * UP Up, Move modifier up in the stack. * DOWN Down, Move modifier down in the stack.
-    :type direction: typing.Union[str, int]
+    :type direction: typing.Union[int, str]
     '''
 
     pass
@@ -1101,31 +1101,31 @@ def strip_modifier_remove(name: str = "Name"):
     pass
 
 
-def strip_transform_clear(property: typing.Union[str, int] = 'ALL'):
+def strip_transform_clear(property: typing.Union[int, str] = 'ALL'):
     ''' Reset image transformation to default value
 
     :param property: Property, Strip transform property to be reset * POSITION Position, Reset strip transform location. * SCALE Scale, Reset strip transform scale. * ROTATION Rotation, Reset strip transform rotation. * ALL All, Reset strip transform location, scale and rotation.
-    :type property: typing.Union[str, int]
+    :type property: typing.Union[int, str]
     '''
 
     pass
 
 
-def strip_transform_fit(fit_method: typing.Union[str, int] = 'FIT'):
+def strip_transform_fit(fit_method: typing.Union[int, str] = 'FIT'):
     ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param fit_method: Fit Method, Scale fit fit_method * FIT Scale to Fit, Scale image so fits in preview. * FILL Scale to Fill, Scale image so it fills preview completely. * STRETCH Stretch to Fill, Stretch image so it fills preview.
-    :type fit_method: typing.Union[str, int]
+    :type fit_method: typing.Union[int, str]
     '''
 
     pass
 
 
-def swap(side: typing.Union[str, int] = 'RIGHT'):
+def swap(side: typing.Union[int, str] = 'RIGHT'):
     ''' Swap active strip with strip to the right or left
 
     :param side: Side, Side of the strip to swap
-    :type side: typing.Union[str, int]
+    :type side: typing.Union[int, str]
     '''
 
     pass
