@@ -22,6 +22,7 @@ def to_string(unit_system: str,
     :type split_unit: bool
     :param compatible_unit: Whether to use keyboard-friendly units (1m2) or nicer utf-8 ones (1m²).
     :type compatible_unit: bool
+    :rtype: str
     :return: The converted string.
     '''
 
@@ -42,6 +43,7 @@ def to_value(unit_system: str,
     :type str_input: str
     :param str_ref_unit: A reference string from which to extract a default unit, if none is found in str_input .
     :type str_ref_unit: str
+    :rtype: float
     :return: The converted/interpreted value.
     '''
 
