@@ -4,11 +4,9 @@ import freestyle.types
 import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BackboneStretcherShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BackboneStretcherShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > BackboneStretcherShader [Geometry shader]
     '''
 
     def __init__(self, amount: float = 2.0):
@@ -29,7 +27,7 @@ class BackboneStretcherShader:
 
 
 class BezierCurveShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BezierCurveShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > BezierCurveShader [Geometry shader]
     '''
 
     def __init__(self, error: float = 4.0):
@@ -50,15 +48,15 @@ class BezierCurveShader:
 
 
 class BlenderTextureShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `BlenderTextureShader` [Texture shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > BlenderTextureShader [Texture shader]
     '''
 
-    def __init__(self, texture: typing.Union['bpy.types.LineStyleTextureSlot',
-                                             'bpy.types.ShaderNodeTree']):
+    def __init__(self, texture: typing.Union[
+            'bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']):
         ''' Builds a BlenderTextureShader object.
 
         :param texture: A line style texture slot or a shader node tree to define a set of textures.
-        :type texture: typing.Union['bpy.types.LineStyleTextureSlot', 'bpy.types.ShaderNodeTree']
+        :type texture: typing.Union['bpy.types.ShaderNodeTree', 'bpy.types.LineStyleTextureSlot']
         '''
         pass
 
@@ -72,13 +70,11 @@ class BlenderTextureShader:
 
 
 class CalligraphicShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `CalligraphicShader` [Thickness Shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > CalligraphicShader [Thickness Shader]
     '''
 
     def __init__(self, thickness_min: float, thickness_max: float,
-                 orientation: typing.
-                 Union[typing.Sequence[float], 'mathutils.Vector'],
-                 clamp: bool):
+                 orientation: 'mathutils.Vector', clamp: bool):
         ''' Builds a CalligraphicShader object.
 
         :param thickness_min: The minimum thickness in the direction perpendicular to the main direction.
@@ -86,7 +82,7 @@ class CalligraphicShader:
         :param thickness_max: The maximum thickness in the main direction.
         :type thickness_max: float
         :param orientation: The 2D vector giving the main direction.
-        :type orientation: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :type orientation: 'mathutils.Vector'
         :param clamp: If true, the strokes are drawn in black when the stroke direction is between -90 and 90 degrees with respect to the main direction and drawn in white otherwise. If false, the strokes are always drawn in black.
         :type clamp: bool
         '''
@@ -102,7 +98,7 @@ class CalligraphicShader:
 
 
 class ColorNoiseShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ColorNoiseShader` [Color shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > ColorNoiseShader [Color shader]
     '''
 
     def __init__(self, amplitude: float, period: float):
@@ -125,7 +121,7 @@ class ColorNoiseShader:
 
 
 class ConstantColorShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstantColorShader` [Color shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > ConstantColorShader [Color shader]
     '''
 
     def __init__(self,
@@ -156,7 +152,7 @@ class ConstantColorShader:
 
 
 class ConstantThicknessShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstantThicknessShader` [Thickness shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > ConstantThicknessShader [Thickness shader]
     '''
 
     def __init__(self, thickness: float):
@@ -177,7 +173,7 @@ class ConstantThicknessShader:
 
 
 class ConstrainedIncreasingThicknessShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ConstrainedIncreasingThicknessShader` [Thickness shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > ConstrainedIncreasingThicknessShader [Thickness shader]
     '''
 
     def __init__(self, thickness_min: float, thickness_max: float,
@@ -194,7 +190,7 @@ class ConstrainedIncreasingThicknessShader:
         pass
 
     def shade(self, stroke: 'freestyle.types.Stroke'):
-        ''' Same as the `IncreasingThicknessShader`, but here we allow the user to control the thickness/length ratio so that we don't get fat short lines.
+        ''' Same as the IncreasingThicknessShader , but here we allow the user to control the thickness/length ratio so that we don't get fat short lines.
 
         :param stroke: A Stroke object.
         :type stroke: 'freestyle.types.Stroke'
@@ -203,7 +199,7 @@ class ConstrainedIncreasingThicknessShader:
 
 
 class GuidingLinesShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `GuidingLinesShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > GuidingLinesShader [Geometry shader]
     '''
 
     def __init__(self, offset: float):
@@ -224,7 +220,7 @@ class GuidingLinesShader:
 
 
 class IncreasingColorShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingColorShader` [Color shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > IncreasingColorShader [Color shader]
     '''
 
     def __init__(self, red_min: float, green_min: float, blue_min: float,
@@ -261,7 +257,7 @@ class IncreasingColorShader:
 
 
 class IncreasingThicknessShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingThicknessShader` [Thickness shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > IncreasingThicknessShader [Thickness shader]
     '''
 
     def __init__(self, thickness_A: float, thickness_B: float):
@@ -284,13 +280,13 @@ class IncreasingThicknessShader:
 
 
 class PolygonalizationShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `PolygonalizationShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > PolygonalizationShader [Geometry shader]
     '''
 
     def __init__(self, error: float):
         ''' Builds a PolygonalizationShader object.
 
-        :param error: The error we want our polygonal approximation to have with respect to the original geometry. The smaller, the closer the new stroke is to the orinal one. This error corresponds to the maximum distance between the new stroke and the old one.
+        :param error: The error we want our polygonal approximation to have with respect to the original geometry. The smaller, the closer the new stroke is to the original one. This error corresponds to the maximum distance between the new stroke and the old one.
         :type error: float
         '''
         pass
@@ -319,7 +315,7 @@ class RoundCapShader:
 
 
 class SamplingShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SamplingShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > SamplingShader [Geometry shader]
     '''
 
     def __init__(self, sampling: float):
@@ -340,7 +336,7 @@ class SamplingShader:
 
 
 class SmoothingShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SmoothingShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > SmoothingShader [Geometry shader]
     '''
 
     def __init__(self,
@@ -383,7 +379,7 @@ class SmoothingShader:
 
 
 class SpatialNoiseShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `SpatialNoiseShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > SpatialNoiseShader [Geometry shader]
     '''
 
     def __init__(self, amount: float, scale: float, num_octaves: int,
@@ -421,7 +417,7 @@ class SquareCapShader:
 
 
 class StrokeTextureStepShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `StrokeTextureStepShader` [Texture shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > StrokeTextureStepShader [Texture shader]
     '''
 
     def __init__(self, step: float):
@@ -442,7 +438,7 @@ class StrokeTextureStepShader:
 
 
 class ThicknessNoiseShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `ThicknessNoiseShader` [Thickness shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > ThicknessNoiseShader [Thickness shader]
     '''
 
     def __init__(self, amplitude: float, period: float):
@@ -465,7 +461,7 @@ class ThicknessNoiseShader:
 
 
 class TipRemoverShader:
-    ''' Class hierarchy: `freestyle.types.StrokeShader` > `TipRemoverShader` [Geometry shader]
+    ''' Class hierarchy: freestyle.types.StrokeShader > TipRemoverShader [Geometry shader]
     '''
 
     def __init__(self, tip_length: float):
