@@ -1,10 +1,10 @@
 import sys
 import typing
-from . import geometry
 from . import noise
-from . import interpolate
+from . import geometry
 from . import bvhtree
 from . import kdtree
+from . import interpolate
 
 
 class Color:
@@ -156,11 +156,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -473,11 +473,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -735,11 +735,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
@@ -2094,11 +2094,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(other: typing.Union['Matrix', 'Quaternion', 'Euler']):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Matrix', 'Quaternion', 'Euler']
         '''
         pass
 
